@@ -8,7 +8,17 @@ pub fn admin_command(matches: &ArgMatches) -> Result<CliCommand, CliError> {
         Some(("cancel", matches)) => Ok(CliCommand::AdminCancelTask {
             address: parse_pubkey(&"address".into(), matches)?,
         }),
-        Some(("health", _matches)) => Ok(CliCommand::AdminScheduleHealthCheck),
+        Some(("health", matches)) => admin_health_command(matches),
+        _ => Err(CliError::CommandNotRecognized(
+            matches.subcommand().unwrap().0.into(),
+        )),
+    }
+}
+
+fn admin_health_command(matches: &ArgMatches) -> Result<CliCommand, CliError> {
+    match matches.subcommand() {
+        Some(("reset", _matches)) => Ok(CliCommand::AdminHealthReset),
+        Some(("start", _matches)) => Ok(CliCommand::AdminHealthStart),
         _ => Err(CliError::CommandNotRecognized(
             matches.subcommand().unwrap().0.into(),
         )),
